DataTables examples - Server-side processing

# DataTables example Server-side processing

There are many ways to get your data into DataTables, and if you are working with seriously large databases, you might want to consider using the server-side options that DataTables provides. With server-side processing enabled, all paging, searching, ordering etc actions that DataTables performs are handed off to a server where an SQL engine (or similar) can perform these actions on the large data set (after all, that's what the database engine is designed for!). As such, each draw of the table will result in a new Ajax request being made to get the required data.

Server-side processing is enabled by setting the `serverSideDT` option to `true` and providing an Ajax data source through the `ajaxDT` option.

The examples in this section shows server-side processing in use and how it can be customised to suit your needs.